
	*~ WBES calculation
	*~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
	preserve

	use "wbes\Indonesia-2023-full-data.dta", clear
	
	replace k15a = . if inlist(k15a, -9, -8)
	replace k11  = . if inlist(k11, -9, -8)
	
	gen colval_wbes 	= k15a/k11
	codebook colval_wbes if k13==2
		replace colval_wbes=0 if k13==2

	
	collapse 	(mean) colval_wbes_2=colval_wbes 	///
				(median) colval_wbes_1=colval_wbes [aw=wmedian]
				
	gen pivot = 2
	reshape long colval_wbes_, i(pivot) j(cat)
	rename colval_wbes colval_
	
	tempfile wbes
	save `wbes'
	
	restore
	
	*~ KUR survey calculation
	*~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
	preserve
	
	use "Survey of KUR borrowers\rf05_deidentified.dta", clear
	
	global output "Output"
	global data_c "Data Created"
	
		*~ Generating New Variable based on RF05
		*~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
		sort id_unique rf05b rf05a
		gen number 				=_n		
			
		gen kur 			 = rf05c == 1 | rf05c == 2 | rf05c == 3
			replace kur		 = . if rf05c == 98	
		
		egen order_loan			= rank(number), by(id_unique)	
		egen last_loan 			= max(order_loan), by(id_unique)
		keep if order_loan 		== last_loan
			
		merge 1:1 id_unique using "Survey of KUR borrowers\main_deidentified.dta"
		drop _merge
		
	gen colval			= rf07/rf05a if rf07 ~= .
	keep if kur 		== 1
	replace colval		= . if id_unique == "S2_103" | id_unique == "S5_1483"
	
	collapse	(mean) colval_2=colval 	///
				(median) colval_1=colval [fw=wgt]
		
	gen pivot 			= 1
	reshape long colval_, i(pivot) j(cat)
	
	tempfile kur_survey
	save `kur_survey'
	
	restore
	
	*~ Appending
	*~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~	
	preserve
	
	use `wbes', clear
	append using `kur_survey'
	
	la define pivot_lab 	///
		1 "KUR" 			///
		2 "Other loans"
	la value pivot pivot_lab
	
	la define cat_lab 		///
		1 "Median" 			///
		2 "Average" 
	la value cat cat_lab	
	
	replace colval_ 		= round(colval_, 0.1)
	
	gr bar colval_, over(pivot) over(cat) 					///
		blabel(bar, size(small)) ylabel(, labsize(small)) 	///
		ylabel(0(1)5) 										///
		ytitle("")											///
		title("Ratio of Collateral Value to Loan Amount", 	///
			size(medium) span) 	 							///
		note(`"Source: For KUR loans, survey of KUR borrowers;"' `"For other loans, 2023 World Bank Enterprise Surveys"', position(7) 	///
			span size(vsmall))	
	graph export "$output\[KUR] Figure 10.png", replace 		

	restore
		
		