
**************************************
* IFLS data crunching
**************************************

	preserve
	
	*~ Business Section
	*~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
	use "IFLS\b2_nt2_2014.dta", clear
	
	rename hhid14 hhid
	keep hhid nt_num nt05aa nt18 nt22 nt23
	keep if nt18 == 1 		// keep only if business is still running
	drop nt18
	
	/*
	nt05aa 	--> PID of household who primarily responsible
	nt22 	--> how many unpaid worker?
	nt23 	--> how many paid worker?
	*/
	
	reshape wide nt05aa nt22 nt23, i(hhid) j(nt_num)
	
	tempfile nt_2014
	save `nt_2014'	
	*~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
	
	*~ Roster Section
	*~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~	
	use "IFLS\bk_ar1_2014.dta", clear
	
	keep hhid14 pidlink pid14 ar07
	rename hhid14 hhid
	rename ar07 sex
	
	tempfile ar_2014
	save `ar_2014'
	*~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
	
	*~ Weight Section
	*~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
	use "IFLS\ptrack_2014.dta", clear
	
	tostring pid14, replace
	egen hhid_pid14 	= concat(hhid14 pid14)
	
	drop if hhid_pid14 == "."
	
	duplicates tag hhid_pid14, gen(x)
	gsort hhid_pid14 -pwt14xa
	by hhid_pid14: drop if [_n] == 2 & x > 0
	
	keep hhid_pid14 pwt14xa
	
	tempfile pweight_2014
	save `pweight_2014'
	*~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
	
	
	*~ Merging Section
	*~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~	
	use `nt_2014', clear
	
	merge 1:m hhid using `ar_2014'
	keep if _merge == 3
	drop _merge
	
	gen biz_own = 1 if nt05aa1 == pid14
		replace biz_own = 2 if nt05aa2 == pid14
	
	keep if inlist(biz_own, 1, 2)
	
	tostring pid14, replace
	egen hhid_pid14 	= concat(hhid pid14)
	
	merge 1:1 hhid_pid14 using `pweight_2014'
	keep if _merge == 3
	
	gen num_worker 		= nt221 + nt231 if biz_own == 1
	replace num_worker 	= nt222 + nt232 if biz_own == 2
	
	gen num_paidworker 		= nt231 if biz_own == 1
	replace num_paidworker 	= nt232 if biz_own == 2	
		
	gen female = 1 if sex == 3
	replace female = 0 if sex == 1
	
	*** Define microentrepreneur as number of worker < 5
	sum female [aw = pwt14xa] if num_paidworker < 5
	local female_micro = `r(mean)'
	disp "Percentage of female microentrepreneur is `female_micro'"
		*Benchmark: Hillary's number is 49.4
		
	collapse (mean) female [aw=pwt14xa]	if num_paidworker < 5
	gen pivot = 2
	
	tempfile ifls2014
	save `ifls2014'
	*~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~	
	
	restore
	
**************************************
* KUR survey data crunching
**************************************
	
	use "Survey of KUR borrowers\rf05_deidentified_replication.dta", clear
	
	global output "Output"
	global data_c "Data Created"
	
		*~ Generating New Variable based on RF05
		*~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
		sort id_unique rf05b rf05a
		gen number 				=_n
			
		gen kur 			 = rf05c == 1 | rf05c == 2 | rf05c == 3
			replace kur		 = . if rf05c == 98	
		
		egen order_loan			= rank(number), by(id_unique)	
		egen last_loan 			= max(order_loan), by(id_unique)
		keep if order_loan 		== last_loan
			
		merge 1:1 id_unique using "Survey of KUR borrowers\main_deidentified_replication.dta"
		drop _merge
		
	gen female 				= ir01c == 3
	sum female if kur == 1 [fw=wgt]
	
	collapse (mean) female if kur == 1 [fw=wgt]
	gen pivot = 1
		
**************************************
* Combining both data
**************************************	
	preserve
	
	append using `ifls2014'
	
	la define pivot_lab 		///
		1 "KUR borrowers" 		///
		2 "Microentrepreneurs" 	
	la value pivot pivot_lab
	
	replace female 		= round(female*100, 0.1)
	
	gr bar female, over(pivot)				///
		blabel(bar, size(small)) ylabel(, labsize(small)) 	///
		ylabel(0(10)55) 									///
		ytitle("Percent")									///
		title(`"Share of KUR Borrowers and Microentrepreneurs in"' `"Indonesia who are Female"', 	///
			size(medium) span) 	 							///
		note(`"Source: KUR borrowers: survey of KUR borrowers;"' `"Microentreprises: Indonesia Family Life Survey 2014"', position(7) 	///
			span size(vsmall))
	graph export "$output\[KUR] Figure 11.png", replace 		
	
	restore
