
	use "Survey of KUR borrowers\main_deidentified.dta", clear
	/* 
		rf01b 	-> Non-KUR Loans
		rf01cc 	-> Micro Finance Institutions
		rf01dd 	-> Digital Lender
		rf01e 	-> Regional Development Banks
		
		fl02a 	-> Non-KUR Loans
		fl02b 	-> Micro Finance Institutions
		fl02c 	-> Digital Lender
		fl02d 	-> Regional Development Banks
	*/
	
	gen prior_1 		= fl02a == 1
	gen prior_2 		= fl02b == 1
	gen prior_3 		= fl02c == 1
	gen prior_4 		= fl02d == 1
	
	gen post_1 			= rf01b  == 1
	gen post_2	 		= rf01cc == 1
	gen post_3 			= rf01dd == 1
	gen post_4 			= rf01e  == 1
	
	preserve
	
	collapse (mean) prior_* post_* [fw = wgt]
	gen pivot = 1
	
	reshape long prior_ post_, i(pivot) j(cat)
	
	la define figure8_label 	///
		1 "Non-Kur Loans" 				///
		2 "Micro Finance Institutions" 	///
		3 "Digital Lender" 				///
		4 "Reginal Development Banks" 
		
	gen lab = ""
	forvalue i = 1/4 	{
	
		local laba: label figure8_label `i'
		replace lab = `"`laba'"' if cat == `i'
	
	}
	
	replace prior_ = round(prior_*100, 1)
	replace post_  = round(post_*100, 1)
	
	graph bar prior_ post, over(lab, sort(cat) label(labsize(small))) 			///
		blabel(bar, size(small)) ylabel(, labsize(small)) 						///
		title("Formal Financing Used Before and After Receiving KUR", size(medium) span) 		///
		legend(col(1) row(2) size(small) order(1 "Prior to receiving KUR for the first time"  	///
			2 "After receiving KUR for the first time") region(lstyle(none)) 	///
			symxsize(*0.5) pos(6)) 												///
		note("Source: Author calculations using survey of KUR borrowers", 		///
			position(5) span size(vsmall))										///
		ylabel(0(2)11)	
	graph export "$output\[KUR] Figure 5.png", replace 
	
	restore			

	
	
