

	preserve
	
	use "Survey of KUR borrowers\rf05_deidentified.dta", clear
	
	global output "Output"
	global data_c "Data Created"
	
	*~ Generating New Variable based on RF05
	*~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
	sort id_unique rf05b rf05a
	gen number 				=_n
		
	gen threshold		  = .
		replace threshold = 5000000 if rf05b < 2011
		replace threshold = 20000000 if rf05b >= 2011 & rf05b < 2016
		replace threshold = 25000000 if rf05b > 2015 & rf05b < 2020
		replace threshold = 50000000 if rf05b >= 2020 & rf05b ~= .	
		
 	gen kur 			 = rf05c == 1 | rf05c == 2 | rf05c == 3
		replace kur		 = . if rf05c == 98
	
	gen kur_non			 = rf05c == 4	
		
	gen kur_micro 		  = kur == 1 & rf05a <= threshold
		replace kur_micro = . if kur == .
		replace kur_micro = 0 if kur_micro ==.
		
	gen kur_small 		  = kur == 1 & rf05a > threshold & rf05a ~=.
		replace kur_small = . if kur == .
		replace kur_small = 0 if kur_small ==.		
	
	egen order_loan			= rank(number), by(id_unique)	
	egen last_loan 			= max(order_loan), by(id_unique)
	keep if order_loan 		== last_loan
	
	merge 1:1 id_unique using "Survey of KUR borrowers\main_deidentified.dta"
	drop _merge
	*~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~	
	
	*~ Generating New Variable based on merged data
	*~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~	
	gen collateral 		= rf07 > 0
	
	gen loan_type			= .
		replace loan_type	= 1 if kur_micro == 1 
		replace loan_type	= 2 if kur_small == 1
		replace loan_type	= 3 if kur_non 	 == 1
	
	collapse (mean) collateral [fw=wgt], by(loan_type)
	drop if loan_type == .	
	
	gen label 		= ""
	replace label 	= "Micro KUR" if loan_type == 1
	replace label 	= "Small KUR" if loan_type == 2
	replace label 	= "Non-KUR commercial loan" if loan_type == 3 
	
	replace collateral = round(collateral*100, 0.01)
		
	*~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~	
	
	gr bar collateral /*if loantype_miss == 0*/, over(label, sort(loan_type) label(labsize(small))) 				///	
		title("% Firms Who Were Required to Submit Collateral by Type of Loan", 													///
			size(medium) span) 																			///
		blabel(bar, size(small)) ylabel(, labsize(small)) 												///
		ytitle("Percent") 																				///
		subtitle(" ", margin(l+0 r+0 b-1 t-1)) 															///
		note("Source: Author calculations using survey of KUR borrowers", position(6) 					///
			span size(vsmall))																			///
		ylabel(0(20)105)	
	graph export "$output\[KUR] Figure 9.png", replace 		
			
	
	restore
