
	use "Survey of KUR borrowers\main_deidentified.dta", clear
	
	gen fulltime 			= we01_a
		replace fulltime 	= cl03_a if we01_a == . & (ir05==2|ir05==3)
	gen parttime 			= we01_b
		replace parttime 	= cl03_b if we01_b == . & (ir05==2|ir05==3)		
	gen unpaid 				= we01_c
		replace unpaid 		= cl03_c if we01_c == . & (ir05==2|ir05==3)	
	gen tot_worker 			= we01_d
		replace tot_worker 	= cl03_d if we01_d == . & (ir05==2|ir05==3)		

	gen total_paid 			= fulltime + parttime
	gen w_total_paid 		= fulltime + parttime
		replace w_total_paid = 30 if total_paid > 30
		
	gen w_tot_worker 		 = tot_worker
		replace w_tot_worker = 30 if tot_worker > 30
	
	*~ Panel A
	*~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
	preserve
	
	gen micro_1 			 = 	fulltime 	 < 5	
	gen micro_2 			 = 	w_total_paid < 5
	gen micro_3		 		 = 	w_tot_worker < 5
	
	collapse (mean) micro_* [fw=wgt]
	gen pivot = 1
	
	reshape long micro_, i(pivot) j(cat)
	
	gen label = ""
	replace label 	= "Full-time salary" if cat == 1
	replace label 	= "Paid workers (full and part-time)" if cat == 2
	replace label 	= "All workers (paid and unpaid)" if cat == 3
	
	replace micro_ 	= round(micro_*100, 0.1)
	
	gr bar micro_, over(label, label(labsize(small)) sort(cat) relabel(2 `" "Paid workers" "full and part-time" "' 3 `" "All workers" "(paid and unpaid)" "')) 	///
		blabel(bar, size(small)) 	///
		ytitle("Percentage") 		///
		title("Panel A: % of Firms with Less than 5 Workers", size(medium) span) 	///
		note("Source: Author calculations using survey of KUR borrowers", 	///
			position(7) span size(vsmall))
	graph export "$output\[KUR] Figure A.1 - Panel A.png", replace
	
	restore
	
	*~ Panel B
	*~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~	
	preserve
	
	gen onewo_1 			 = 	fulltime 	 >= 1	
	gen onewo_2 			 = 	w_total_paid >= 1
	gen onewo_3		 		 = 	w_tot_worker >= 1
	
	collapse (mean) onewo_* [fw=wgt]
	gen pivot = 1
	
	reshape long onewo_, i(pivot) j(cat)
	
	gen label = ""
	replace label 	= "Full-time salary" if cat == 1
	replace label 	= "Paid workers (full and part-time)" if cat == 2
	replace label 	= "All workers (paid and unpaid)" if cat == 3
	
	replace onewo_ 	= round(onewo_*100, 0.1)
	
	gr bar onewo_, over(label, label(labsize(small)) sort(cat) relabel(2 `" "Paid workers" "full and part-time" "' 3 `" "All workers" "(paid and unpaid)" "')) 	///
		blabel(bar, size(small)) 	///
		ytitle("Percentage") 		///
		title("Panel B: % of Firms with At Least One Worker", size(medium) span) 	///
		note("Source: Author calculations using survey of KUR borrowers", 	///
			position(7) span size(vsmall))
	graph export "$output\[KUR] Figure A.1 - Panel B.png", replace
	
	restore	
	
	*~ Panel B
	*~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~		
	preserve
	
	gen onenum_1 			 = 	fulltime if fulltime 	 >= 1	
	gen onenum_2 			 = 	w_total_paid if w_total_paid >= 1
	gen onenum_3		 	 = 	w_tot_worker
	
	collapse (mean) onenum_* [fw=wgt]
	gen pivot = 1
	
	reshape long onenum_, i(pivot) j(cat)
	
	gen label = ""
	replace label 	= "Full-time salary" if cat == 1
	replace label 	= "Paid workers (full and part-time)" if cat == 2
	replace label 	= "All workers (paid and unpaid)" if cat == 3
	
	replace onenum_ 	= round(onenum_, 0.1)
	
	gr bar onenum_, over(label, label(labsize(small)) sort(cat) relabel(2 `" "Paid workers" "full and part-time" "' 3 `" "All workers" "(paid and unpaid)" "')) 	///
		blabel(bar, size(small)) 	///
		title("Panel C: Average Number of Workers for Firms with At Least One Worker", size(medium) span) 	///
		note("Source: Author calculations using survey of KUR borrowers", 	///
			position(7) span size(vsmall)) ///
		ytitle("")	
	graph export "$output\[KUR] Figure A.1 - Panel C.png", replace
	
	restore
		