	
	*~ Panel A
	*~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~	
	use "Survey of KUR borrowers\bi03_deidentified.dta", clear

		bysort id_unique: gen num_owner 	= _N
			
		keep id_unique num_owner
		bysort id_unique: keep if [_n] == 1
		
		merge 1:1 id_unique using "Survey of KUR borrowers\main_deidentified.dta"
		drop _merge
		
		gen female 				= ir01c == 3
		replace num_owner 		= 3 if num_owner > 3
		
		gen num_owner_1 		= num_owner == 1
		gen num_owner_2 		= num_owner == 2
		gen num_owner_3 		= num_owner == 3
		
		** Overall
		preserve
		
			collapse (mean) num_owner_1 num_owner_2 num_owner_3 [fw = wgt]
			gen pivot = 1
			reshape long num_owner_, i(pivot) j(cat)
			
			tempfile overall
			save `overall'
		
		restore
		
		** Female
		preserve
		
			collapse (mean) num_owner_1 num_owner_2 num_owner_3 [fw = wgt] if female == 1
			gen pivot = 3
			reshape long num_owner_, i(pivot) j(cat)
			
			tempfile female
			save `female'
		
		restore
		
		** Male
		preserve
		
			collapse (mean) num_owner_1 num_owner_2 num_owner_3 [fw = wgt] if female == 0
			gen pivot = 2
			reshape long num_owner_, i(pivot) j(cat)
			
			tempfile male
		save `male'
		
		restore
		
		** Append
		use `overall', replace
		append using `male' `female'

		la define pivot_label 		///
			1 "Overall" 			///
			2 "Men" 				///
			3 "Women" 
		la value pivot pivot_label
		
		la define cat_label 		///
			1 "1 Owner" 			///
			2 "2 Owners" 			///
			3 "Over 3 owners" 	
		la value cat cat_label
		
		replace num_owner_ 	= round(num_owner_*100, 0.1)
		
		gr bar num_owner_, over(pivot, label(labsize(small))) over(cat, label(labsize(small))) asyvars			///
			blabel(bar, size(small)) 	///
			title("Panel A: Number of KUR Firm Owners with Gender Differences", size(medium) span) 	///
			note("Source: Author calculations using survey of KUR borrowers", 	///
				position(7) span size(vsmall)) ///
			legend(col(3) row(1) size(small) order(1 "Overall" 2 "Men" 3 "Women")  	///
				region(lstyle(none)) 												///
				symxsize(*0.5) pos(6)) 												///			
			ytitle("Percentage")
		
	graph export "$output\[KUR] Figure A.2 - Panel A.png", replace
	*~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~	
	
	*~ Panel B
	*~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~		
	use "Survey of KUR borrowers\bi05_deidentified.dta", clear	
		
		bysort id_unique: gen num_manager 	= _N
		
		keep id_unique num_manager
		bysort id_unique: keep if [_n] == 1
		
		merge 1:1 id_unique using "Survey of KUR borrowers\main_deidentified.dta"
		drop _merge
		
		gen female 				= ir01c == 3	
		
		replace num_manager 	= 3 if num_manager > 3
		
		gen num_manager_1 		= num_manager == 1
		gen num_manager_2 		= num_manager == 2
		gen num_manager_3 		= num_manager == 3		
	
		** Overall
		preserve
		
			collapse (mean) num_manager_1 num_manager_2 num_manager_3 [fw = wgt]
			gen pivot = 1
			reshape long num_manager_, i(pivot) j(cat)
			
			tempfile overall_manager
			save `overall_manager'
		
		restore
		
		** Female
		preserve
		
			collapse (mean) num_manager_1 num_manager_2 num_manager_3 [fw = wgt] if female == 1
			gen pivot = 3
			reshape long num_manager_, i(pivot) j(cat)
			
			tempfile female_manager
			save `female_manager'
		
		restore
		
		** Male
		preserve
		
			collapse (mean) num_manager_1 num_manager_2 num_manager_3 [fw = wgt] if female == 0
			gen pivot = 2
			reshape long num_manager_, i(pivot) j(cat)
			
			tempfile male_manager
		save `male_manager'
		
		restore
		
		** Append
		use `overall_manager', replace
		append using `male_manager' `female_manager'	
		
		la define pivot_label 		///
			1 "Overall" 			///
			2 "Men" 				///
			3 "Women" 
		la value pivot pivot_label
		
		la define cat_label 		///
			1 "1 Manager" 			///
			2 "2 Manager" 			///
			3 "Over 3 managers" 	
		la value cat cat_label
		
		replace num_manager_ 	= round(num_manager_*100, 0.1)
		
		gr bar num_manager_, over(pivot, label(labsize(small))) over(cat, label(labsize(small))) asyvars			///
			blabel(bar, size(small)) 	///
			title("Panel A: Number of KUR Firm Managers with Gender Differences", size(medium) span) 	///
			note("Source: Author calculations using survey of KUR borrowers", 	///
				position(7) span size(vsmall)) ///
			legend(col(3) row(1) size(small) order(1 "Overall" 2 "Men" 3 "Women")  	///
				region(lstyle(none)) 												///
				symxsize(*0.5) pos(6)) 												///			
			ytitle("Percentage")
		
	graph export "$output\[KUR] Figure A.2 - Panel B.png", replace		
	*~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~		
	
	*~ Panel C
	*~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~	
	use "Survey of KUR borrowers\bi03_deidentified.dta", clear	
	
		bysort id_unique: gen order = _n
		keep id_unique bi03a order
		reshape wide bi03a, i(id_unique) j(order)

		merge 1:1 id_unique using "Survey of KUR borrowers\main_deidentified.dta"
		drop _merge
		drop if bi03a2 == .

		gen female 				= ir01c == 3	
		
		gen rel_owner_1 		= .
		gen rel_owner_2 		= .
		gen rel_owner_3 		= .
		gen rel_owner_4 		= .
		
		forvalue i = 1/7 	{
			
			forvalue j = 1/4 	{
			
				local k = `j' + 1
				replace rel_owner_`j' = 1 if bi03a`i' == `k'
				
			}
			
		}
		
		replace rel_owner_1 	= 0 if rel_owner_1 == .
		replace rel_owner_2 	= 0 if rel_owner_2 == .
		replace rel_owner_3 	= 0 if rel_owner_3 == .
		replace rel_owner_4 	= 0 if rel_owner_4 == .
			

		** Overall
		preserve
		
			collapse (mean) rel_owner_1 rel_owner_2 rel_owner_3 rel_owner_4 [fw = wgt]
			gen pivot = 1
			reshape long rel_owner_, i(pivot) j(cat)
			
			tempfile overall_rel
			save `overall_rel'
		
		restore
		
		** Female
		preserve
		
			collapse (mean) rel_owner_1 rel_owner_2 rel_owner_3 rel_owner_4 if female == 1 [fw = wgt]
			gen pivot = 3
			reshape long rel_owner_, i(pivot) j(cat)
			
			tempfile female_rel
			save `female_rel'
		
		restore
		
		** Male
		preserve
		
			collapse (mean) rel_owner_1 rel_owner_2 rel_owner_3 rel_owner_4 if female == 0 [fw = wgt]
			gen pivot = 2
			reshape long rel_owner_, i(pivot) j(cat)
			
			tempfile male_rel
		save `male_rel'
		
		restore
		
		** Append
		use `overall_rel', replace
		append using `male_rel' `female_rel'			
		
		la define pivot_label 		///
			1 "Overall" 			///
			2 "Men" 				///
			3 "Women" 
		la value pivot pivot_label
		
		la define cat_label 			///
			1 "Spouse" 					///
			2 "Another family Member" 	///
			3 "Friends or neighbors" 	///
			4 "Third parties"
		la value cat cat_label
		
		replace rel_owner_ 	= round(rel_owner_*100, 0.1)
		
		gr bar rel_owner_, over(pivot, label(labsize(small))) over(cat, label(labsize(small))) asyvars			///
			blabel(bar, size(small)) 	///
			title("Panel C: Relationship to Co-Owner for Businesses with Multiple Owners, by Gender", size(medium) span) 	///
			note("Source: Author calculations using survey of KUR borrowers", 	///
				position(7) span size(vsmall)) ///
			legend(col(3) row(1) size(small) order(1 "Overall" 2 "Men" 3 "Women")  	///
				region(lstyle(none)) 												///
				symxsize(*0.5) pos(6)) 												///			
			ytitle("Percentage")
		
	graph export "$output\[KUR] Figure A.2 - Panel C.png", replace			
	*~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~		
	
	*~ Panel D
	*~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
	use "Survey of KUR borrowers\bi05_deidentified.dta", clear	
		
		bysort id_unique: gen order = _n
		keep id_unique bi05a order
		reshape wide bi05a, i(id_unique) j(order)

		merge 1:1 id_unique using "Survey of KUR borrowers\main_deidentified.dta"
		drop _merge
		drop if bi05a2 == .
		
		gen female 				= ir01c == 3	
				
		egen rel_manager_1 		= anymatch(bi05a*), values(2)
		egen rel_manager_2 		= anymatch(bi05a*), values(3)
		egen rel_manager_3 		= anymatch(bi05a*), values(4)
		egen rel_manager_4 		= anymatch(bi05a*), values(5)

		** Overall
		preserve
		
			collapse (mean) rel_manager_1 rel_manager_2 rel_manager_3 rel_manager_4 [fw = wgt]
			gen pivot = 1
			reshape long rel_manager_, i(pivot) j(cat)
			
			tempfile overall_rel_man
			save `overall_rel_man'
		
		restore
		
		** Female
		preserve
		
			collapse (mean) rel_manager_1 rel_manager_2 rel_manager_3 rel_manager_4 if female == 1 [fw = wgt]
			gen pivot = 3
			reshape long rel_manager_, i(pivot) j(cat)
			
			tempfile female_rel_man
			save `female_rel_man'
		
		restore
		
		** Male
		preserve
		
			collapse (mean) rel_manager_1 rel_manager_2 rel_manager_3 rel_manager_4 if female == 0 [fw = wgt]
			gen pivot = 2
			reshape long rel_manager_, i(pivot) j(cat)
			
			tempfile male_rel_man
		save `male_rel_man'
		
		restore
		
		** Append
		use `overall_rel_man', replace
		append using `male_rel_man' `female_rel_man'				
		
		la define pivot_label 		///
			1 "Overall" 			///
			2 "Men" 				///
			3 "Women" 
		la value pivot pivot_label
		
		la define cat_label 			///
			1 "Spouse" 					///
			2 "Another family Member" 	///
			3 "Friends or neighbors" 	///
			4 "Third parties"
		la value cat cat_label
		
		replace rel_manager_ 	= round(rel_manager_*100, 0.1)

		gr bar rel_manager_, over(pivot, label(labsize(small))) over(cat, label(labsize(small))) asyvars			///
			blabel(bar, size(small)) 	///
			title("Panel D: Relationship to Co-Manager for Businesses with Multiple Owners, by Gender", size(medium) span) 	///
			note("Source: Author calculations using survey of KUR borrowers", 	///
				position(7) span size(vsmall)) ///
			legend(col(3) row(1) size(small) order(1 "Overall" 2 "Men" 3 "Women")  	///
				region(lstyle(none)) 												///
				symxsize(*0.5) pos(6)) 												///			
			ytitle("Percentage")
		
	graph export "$output\[KUR] Figure A.2 - Panel D.png", replace			
	*~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~		
	
/*
		gen rel_manager_1 		= .
		gen rel_manager_2 		= .
		gen rel_manager_3 		= .
		gen rel_manager_4 		= .		
			
		forvalue i = 1/6 	{
			
			forvalue j = 1/4 	{
			
				local k = `j' + 1
				replace rel_manager_`j' = 1 if bi05a`i' == `k'
				
			}
			
		}
		
		replace rel_manager_1 	= 0 if rel_manager_1 == .
		replace rel_manager_2 	= 0 if rel_manager_2 == .
		replace rel_manager_3 	= 0 if rel_manager_3 == .
		replace rel_manager_4 	= 0 if rel_manager_4 == .	
*/			
		
		
		
		
		
		
